pub struct Pool {
pub enabled: bool,
pub owner: Pubkey,
pub mint_a: Pubkey,
pub mint_b: Pubkey,
pub token_a_reserves: u128,
pub token_b_reserves: u128,
pub shift: u128,
pub royalties: u64,
pub vertigo_fees: u64,
pub bump: u8,
pub fee_params: FeeParams,
}Fields
enabled: boolowner: Pubkeymint_a: Pubkeymint_b: Pubkeytoken_a_reserves: u128token_b_reserves: u128shift: u128royalties: u64vertigo_fees: u64bump: u8fee_params: FeeParamsTrait Implementations
Sourceimpl BorshDeserialize for Pool
impl BorshDeserialize for Pool
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for Pool
impl CarbonDeserialize for Pool
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl<'de> Deserialize<'de> for Pool
impl<'de> Deserialize<'de> for Pool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more