pub struct PoolCreatedEvent {}Trait Implementations
Sourceimpl BorshDeserialize for PoolCreatedEvent
impl BorshDeserialize for PoolCreatedEvent
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for PoolCreatedEvent
impl CarbonDeserialize for PoolCreatedEvent
const DISCRIMINATOR: &'static [u8]
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl Clone for PoolCreatedEvent
impl Clone for PoolCreatedEvent
Sourcefn clone(&self) -> PoolCreatedEvent
fn clone(&self) -> PoolCreatedEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PoolCreatedEvent
impl Debug for PoolCreatedEvent
Sourceimpl<'de> Deserialize<'de> for PoolCreatedEvent
impl<'de> Deserialize<'de> for PoolCreatedEvent
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for PoolCreatedEvent
impl Hash for PoolCreatedEvent
Sourceimpl PartialEq for PoolCreatedEvent
impl PartialEq for PoolCreatedEvent
Sourceimpl Serialize for PoolCreatedEvent
impl Serialize for PoolCreatedEvent
impl Eq for PoolCreatedEvent
impl StructuralPartialEq for PoolCreatedEvent